BCOM Index
----------

This example code shows how an index can be implemented, this follows the BCOM compuational logic
set out in https://assets.bbhub.io/professional/sites/10/BCOM-Methodology.pdf. 

The model here is simplistic and relies on data provided by the document for
the example cims and other data here. This does not implement logic to
deal with market disruption events, not does it implement the weight->cim
computational logic.

The purpose of this example is to show how HGraph can be used to 
compute an index in a backtest scenario.
